# Read Me

---

### Table of Contents

- [Description](#description)
- [How To Use](#how-to-use)
- [References](#references)
- [License](#license)
- [Author Info](#author-info)

---

## Description

Essa Biblioteca é um wrapper da api do GoogleDrive, foi criada uma classe Drive para facilitar a utilização requests que são regularmente requeridos nos projetos.


#### Bibliotecas utilizadas

- google-api-python-client
- google-auth-httplib2
- google-auth-oauthlib
- oauth2client
- httplib2

[Back To The Top](#read-me)

---

## How To Use
Este projeto consiste em um módulo com a classe Drive, para chamar a classe no seu código basta preencher a linha abaixo
```html
    from GoogleDrive import Drive
```
#### Installation
if you dont have docker on your computer, you can install with the followings commands

```html
    pip install GoogleDriveWrapper
```

---

## References
 - [Flask Quickstart](https://flask.palletsprojects.com/en/2.0.x/quickstart/) documentation
 - [Docker](https://docs.docker.com/get-started/) documentation

[Back To The Top](#read-me)

---

## License

MIT License

Copyright (c) [2021] [João Paulo M de Oliveira]

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

[Back To The Top](#read-me)

---

## Author Info
- GitHub -  [@jpmarques-97](https://github.com/jpmarques-97/)

[Back To The Top](#read-me)


